<!--
  Naver2RSS 1.0
  tidy로 청소한 네이버 뉴스 기사 목록을 RSS로 변환해주는 XSLT
  누가: 신재호 <netj@sparcs.kaist.ac.kr>
  언제: 2004-01-03
  $Id: naver2rss.xsl,v 1.1.1.1 2004/01/25 05:42:57 netj Exp $
  
  신문이나 TV 같은 언론을 RSS로 금방금방 받아보고 싶어서 뚝딱 만들었습니다. :)
  혹시라도 네이버 페이지 생성 방식이 바뀌면 고쳐줘야할 부분들이 생길겁니다. :(
  
  셸 스크립트와 함께 마음대로 가져다 쓰십시오. 다만, 이 코드로 인해 생기는
  문제에 대해서는 저에게 아무런 책임이 없습니다. 혹시라도 개선/제안할 내용이
  있으면 제게도 알려주십시오. 뭐, 코드를 고쳐서 아주 재미있는 기능을 혼자만
  쓰더라도 상관은 하지 않습니다.
  
  혹시라도 네이버 관계자 분들이 이 스크립트나 XSLT를 발견하신다면,
  "이런 변태 짓을 하게 만들었다니!"하면서 제발 경악하시고 어서 네이버에 RSS
  인터페이스를 달아주세요. 다른 언론 사이트 관계자 분들도 마찬가지입니다.

  RSS가 무엇인지 궁금하시다면 http://www.feedvalidator.org/docs/rss2.html 를
  읽어보십시오. RSS를 받아보는 프로그램은
  http://email.about.com/cs/rssfeedreaders/gr/ 또는
  http://www.ourpla.net/cgi-bin/pikie.cgi?RssReaders 를 보십시오.
-->
<xsl:stylesheet version="1.0"
    xmlns:xhtml="http://www.w3.org/1999/xhtml"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="xml"/>
    <xsl:param name="section" select="'속보'"/>
    <xsl:param name="section_id" select="'top'"/>
    <xsl:template match="/">
	<rss version="2.0">
	    <channel>
		<title>네이버 <xsl:value-of select="$section"/> 뉴스</title>
		<link>http://news.naver.com/news_list.php?section=<xsl:value-of select="$section_id"/></link>
		<language>ko</language>
		<!-- 네이버 로고 (난 네이버랑 아무 상관 없는 사람인데 -_-) -->
		<image>
		    <title>네이버 뉴스</title>
		    <url>http://img.news.naver.com/image/news/images/slogo_naver_new.gif</url>
		    <link>http://news.naver.com/</link>
		</image>
		<description/>
		<!-- 이제 기사들 뽑아와서 뿌려주기. tidy가 정리해준 XHTML에는,
		a를 포함하는 각 td마다 기사가 들어있음 -->
		<xsl:apply-templates select="//xhtml:td"/>
	    </channel>
	</rss>
	<xsl:comment>Generated by Naver2RSS/1.0</xsl:comment>
    </xsl:template>
    <xsl:template match="xhtml:td">
	<!-- 첫 번째 a의 내용이 기사 제목이며, @href 속에 주소가 들어있음 -->
	<xsl:variable name="link" select=".//xhtml:a[1]"/>
	<!-- a가 없거나 img가 들어있는 a들은 기사 그림이므로 건너뜀 -->
	<xsl:if test="$link and not($link/xhtml:img)">
	    <item>
		<title>
		    <!-- a에 보이는 내용이 곧 제목 -->
		    <xsl:apply-templates select="$link"/>
		</title>
		<link>
		    <!-- 올바른 URL이 되도록 손보기 -->
		    <xsl:if test="not(starts-with($link/@href, 'http://'))">
			<xsl:text>http://news.naver.com/</xsl:text>
		    </xsl:if>
		    <xsl:value-of select="$link/@href"/>
		</link>
		<!-- 어느 신문, 언제 썼는 지 알아내기 -->
		<xsl:variable name="author_date"
		    select="normalize-space(translate(
		    xhtml:span[1]/xhtml:span, '[]', '  '))"/>
		<xsl:variable name="author" select="substring-before($author_date, ' ')"/>
		<xsl:variable name="date_time" select="substring-after($author_date, ' ')"/>
		<xsl:variable name="date" select="substring-before($date_time, ' ')"/>
		<xsl:variable name="time" select="substring-after($date_time, ' ')"/>
		<author><xsl:value-of select="$author"/></author>
		<description>
		    <xsl:apply-templates select="xhtml:span[2]"/>
		    <!-- 간단한 내용이 있다면 두 번째 span에 들어있음,
		    간추린 소식은 요약이 없고 따라서 span[2]도 없어서
		    빈 내용의 description이 됨 -->
		</description>
		<dc:date>
		    <xsl:value-of select="$date"/> <!-- 날짜 -->
		    <xsl:text>T</xsl:text> <!-- ISO 형식 맞춰주기 -->
		    <xsl:value-of select="$time"/> <!-- 시간 -->
		    <xsl:text>:00</xsl:text> <!-- 초는 없어서 그냥 00으로 -_- -->
		    <xsl:text>+09:00</xsl:text> <!-- 한국 표준시 -->
		</dc:date>
	    </item>
	</xsl:if>
    </xsl:template>
</xsl:stylesheet>
